@@ -40,9 +40,11 @@ from gnomemusic.coreselection import CoreSelection
 from gnomemusic.inhibitsuspend import InhibitSuspend
 from gnomemusic.mpris import MPRIS
 from gnomemusic.musiclogger import MusicLogger
+from gnomemusic.notificationmanager import NotificationManager
 from gnomemusic.pauseonsuspend import PauseOnSuspend
 from gnomemusic.player import Player
 from gnomemusic.scrobbler import LastFmScrobbler
+from gnomemusic.search import Search
 from gnomemusic.widgets.aboutdialog import AboutDialog
 from gnomemusic.widgets.lastfmdialog import LastfmDialog
 from gnomemusic.window import Window
@@ -63,6 +65,9 @@ class Application(Gtk.Application):
         self._window = None
 
         self._log = MusicLogger()
+        self._search = Search()
+
+        self._notificationmanager = NotificationManager(self)
         self._coreselection = CoreSelection()
         self._coremodel = CoreModel(self)
         # Order is important: CoreGrilo initializes the Grilo sources,
@@ -162,6 +167,26 @@ class Application(Gtk.Application):
         """
         return self._window
 
+    @GObject.Property(
+        type=Search, flags=GObject.ParamFlags.READABLE)
+    def search(self):
+        """Get class providing search logic.
+
+        :returns: List model provider class
+        :rtype: Search
+        """
+        return self._search
+
+    @GObject.Property(
+        type=NotificationManager, flags=GObject.ParamFlags.READABLE)
+    def notificationmanager(self):
+        """Get notification manager
+
+        :returns: notification manager
+        :rtype: NotificationManager
+        """
+        return self._notificationmanager
+
     def _set_actions(self):
         action_entries = [
             ('about', self._about, None),
@@ -203,6 +228,7 @@ class Application(Gtk.Application):
     def do_activate(self):
         if not self._window:
             self._window = Window(self)
+            self.notify("window")
             self._window.set_default_icon_name(self.props.application_id)
             if self.props.application_id == "org.gnome.Music.Devel":
                 self._window.get_style_context().add_class('devel')
