@@ -86,7 +86,8 @@ class CoreAlbum(GObject.GObject):
         return disc_model_sort
 
     @GObject.Property(
-        type=Gio.ListModel, default=None, flags=GObject.ParamFlags.READABLE)
+        type=Gfm.SortListModel, default=None,
+        flags=GObject.ParamFlags.READABLE)
     def model(self):
         if self._model is None:
             self._model = self._get_album_model()
@@ -118,7 +119,7 @@ class CoreAlbum(GObject.GObject):
     def selected(self):
         return self._selected
 
-    @selected.setter
+    @selected.setter  # type: ignore
     def selected(self, value):
         if value == self._selected:
             return
@@ -136,19 +137,22 @@ class CoreAlbum(GObject.GObject):
     def thumbnail(self):
         """Album art thumbnail retrieval
 
-        :return: The album art uri or "generic" or "loading"
+        :return: The album art uri or "generic"
         :rtype: string
         """
         if self._thumbnail is None:
-            self._thumbnail = "loading"
+            self._thumbnail = "generic"
             AlbumArt(self._application, self)
 
         return self._thumbnail
 
-    @thumbnail.setter
+    @thumbnail.setter  # type: ignore
     def thumbnail(self, value):
         """Album art thumbnail setter
 
-        :param string value: uri, "generic" or "loading"
+        :param string value: uri or "generic"
         """
         self._thumbnail = value
+
+        if self._thumbnail != "generic":
+            self.props.media.set_thumbnail(self._thumbnail)
