@@ -127,3 +127,6 @@ class CoreArtist(GObject.GObject):
         :param string value: uri or "generic"
         """
         self._thumbnail = value
+
+        if self._thumbnail != "generic":
+            self.props.media.set_thumbnail(self._thumbnail)
