@@ -22,12 +22,14 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
+from __future__ import annotations
 from enum import IntEnum
 from gettext import gettext as _
+from typing import Optional
+import typing
 
 from gi.repository import Gdk, GObject, Gtk
 
-from gnomemusic.player import PlayerPlaylist
 from gnomemusic.search import Search
 from gnomemusic.widgets.albumcover import AlbumCover
 from gnomemusic.widgets.albumwidget import AlbumWidget
@@ -35,6 +37,10 @@ from gnomemusic.widgets.headerbar import HeaderBar
 from gnomemusic.widgets.artistalbumswidget import ArtistAlbumsWidget
 from gnomemusic.widgets.artistsearchtile import ArtistSearchTile
 from gnomemusic.widgets.songwidget import SongWidget
+from gnomemusic.widgets.songwidgetmenu import SongWidgetMenu
+if typing.TYPE_CHECKING:
+    from gnomemusic.application import Application
+    from gnomemusic.coresong import CoreSong
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/SearchView.ui")
@@ -68,13 +74,15 @@ class SearchView(Gtk.Stack):
     _artist_header = Gtk.Template.Child()
     _artist_all_flowbox = Gtk.Template.Child()
     _artist_flowbox = Gtk.Template.Child()
+    _scrolled_album_widget = Gtk.Template.Child()
     _search_results = Gtk.Template.Child()
     _songs_header = Gtk.Template.Child()
     _songs_listbox = Gtk.Template.Child()
+    _songs_listbox_ctrlr = Gtk.Template.Child()
     _view_all_albums = Gtk.Template.Child()
     _view_all_artists = Gtk.Template.Child()
 
-    def __init__(self, application):
+    def __init__(self, application: Application) -> None:
         """Initialize SearchView
 
         :param GtkApplication application: The Application object
@@ -132,10 +140,9 @@ class SearchView(Gtk.Stack):
         self._album_widget.bind_property(
             "selection-mode", self, "selection-mode",
             GObject.BindingFlags.BIDIRECTIONAL)
+        self._scrolled_album_widget.add(self._album_widget)
 
-        self.add(self._album_widget)
-
-        self._scrolled_artist_window = None
+        self._scrolled_artist_window: Optional[Gtk.ScrolledWindow] = None
 
         self._search_mode_active = False
 
@@ -149,17 +156,17 @@ class SearchView(Gtk.Stack):
 
         return False
 
-    def _create_song_widget(self, coresong):
+    def _create_song_widget(self, coresong: CoreSong) -> Gtk.ListBoxRow:
         song_widget = SongWidget(coresong, False, True)
         song_widget.props.show_song_number = False
+        song_widget.props.menu = SongWidgetMenu(
+            self._application, song_widget, coresong)
 
         self.bind_property(
             "selection-mode", song_widget, "selection-mode",
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
 
-        song_widget.connect('button-release-event', self._song_activated)
-
         return song_widget
 
     def _create_album_widget(self, corealbum):
@@ -237,28 +244,57 @@ class SearchView(Gtk.Stack):
         else:
             self.props.search_state = Search.State.NO_RESULT
 
-    def _song_activated(self, widget, event):
+    @Gtk.Template.Callback()
+    def _song_activated(
+            self, list_box: Gtk.ListBox, song_widget: SongWidget) -> bool:
+        if song_widget.props.select_click:
+            song_widget.props.select_click = False
+            return True
+
+        event = Gtk.get_current_event()
+        (_, state) = event.get_state()
         mod_mask = Gtk.accelerator_get_default_mod_mask()
-        if ((event.get_state() & mod_mask) == Gdk.ModifierType.CONTROL_MASK
+        if ((state & mod_mask) == Gdk.ModifierType.CONTROL_MASK
                 and not self.props.selection_mode):
             self.props.selection_mode = True
-            return
+            song_widget.props.select_click = True
+            song_widget.props.coresong.props.selected = True
+            return True
+
+        if self.props.selection_mode:
+            song_widget.props.select_click = True
+            selection_state = song_widget.props.selected
+            song_widget.props.selected = not selection_state
+            song_widget.props.coresong.props.selected = not selection_state
+            return True
 
         (_, button) = event.get_button()
         if (button == Gdk.BUTTON_PRIMARY
                 and not self.props.selection_mode):
-            # self.emit('song-activated', widget)
-
-            self._coremodel.set_player_model(
-                PlayerPlaylist.Type.SEARCH_RESULT, self._model)
-            self._player.play(widget.props.coresong)
-
-        # FIXME: Need to ignore the event from the checkbox.
-        # if self.props.selection_mode:
-        #     widget.props.selected = not widget.props.selected
+            coresong = song_widget.props.coresong
+            self._coremodel.props.active_core_object = coresong
+            self._player.play(coresong)
 
         return True
 
+    @Gtk.Template.Callback()
+    def _songs_listbox_right_click(
+            self, gesture: Gtk.GestureMultiPress, n_press: int, x: int,
+            y: int) -> None:
+        song_widget = self._songs_listbox.get_row_at_y(y)
+
+        _, y0 = song_widget.translate_coordinates(self._songs_listbox, 0, 0)
+        row_height = song_widget.get_allocated_height()
+        rect = Gdk.Rectangle()
+        rect.x = x
+        rect.y = y0 + 0.5 * row_height
+
+        song_context_menu = SongWidgetMenu(
+            self._application, song_widget, song_widget.props.coresong)
+        song_context_menu.props.relative_to = self._songs_listbox
+        song_context_menu.props.pointing_to = rect
+        song_context_menu.popup()
+
     def _on_album_flowbox_size_allocate(self, widget, allocation, data=None):
         nb_children = self._album_filter.get_n_items()
         if nb_children == 0:
@@ -334,17 +370,18 @@ class SearchView(Gtk.Stack):
     def _on_album_activated(self, widget, child, user_data=None):
         corealbum = child.props.corealbum
         if self.props.selection_mode:
+            corealbum.props.selected = not corealbum.props.selected
             return
 
         # Update and display the album widget if not in selection mode
-        self._album_widget.update(corealbum)
+        self._album_widget.props.corealbum = corealbum
 
         self.props.state = SearchView.State.ALBUM
         self._headerbar.props.state = HeaderBar.State.SEARCH
         self._headerbar.props.title = corealbum.props.title
         self._headerbar.props.subtitle = corealbum.props.artist
 
-        self.set_visible_child(self._album_widget)
+        self.set_visible_child(self._scrolled_album_widget)
         self.props.search_mode_active = False
 
     @Gtk.Template.Callback()
@@ -413,8 +450,7 @@ class SearchView(Gtk.Stack):
         if self.props.state == SearchView.State.MAIN:
             with self._model.freeze_notify():
                 def song_select(child):
-                    song_widget = child.get_child()
-                    song_widget.props.coresong.props.selected = value
+                    child.props.coresong.props.selected = value
 
                 self._songs_listbox.foreach(song_select)
                 self._album_flowbox.foreach(child_select)
@@ -426,7 +462,7 @@ class SearchView(Gtk.Stack):
             with self._model.freeze_notify():
                 self._artist_all_flowbox.foreach(child_select)
         elif self.props.state == SearchView.State.ALBUM:
-            view = self.get_visible_child()
+            view = self._album_widget
             if value is True:
                 view.select_all()
             else:
@@ -471,7 +507,7 @@ class SearchView(Gtk.Stack):
         """
         return self._search_mode_active
 
-    @search_mode_active.setter
+    @search_mode_active.setter  # type: ignore
     def search_mode_active(self, value):
         """Set search mode status.
 
