@@ -22,25 +22,34 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gi.repository import GObject, Gtk
+from __future__ import annotations
+import typing
 
-from gnomemusic.player import PlayerPlaylist
-from gnomemusic.widgets.artistalbumwidget import ArtistAlbumWidget
+from gi.repository import GObject, Gtk, Handy
+
+from gnomemusic.widgets.albumwidget import AlbumWidget
+if typing.TYPE_CHECKING:
+    from gnomemusic.application import Application
+    from gnomemusic.coreartist import CoreArtist
 
 
-class ArtistAlbumsWidget(Gtk.ListBox):
+@Gtk.Template(resource_path="/org/gnome/Music/ui/ArtistAlbumsWidget.ui")
+class ArtistAlbumsWidget(Handy.Clamp):
     """Widget containing all albums by an artist
 
-    A vertical list of ArtistAlbumWidget, containing all the albums
+    A vertical list of AlbumWidget, containing all the albums
     by one artist. Contains the model for all the song widgets of
     the album(s).
     """
 
     __gtype_name__ = 'ArtistAlbumsWidget'
 
+    _listbox = Gtk.Template.Child()
+
     selection_mode = GObject.Property(type=bool, default=False)
 
-    def __init__(self, coreartist, application):
+    def __init__(
+            self, coreartist: CoreArtist, application: Application) -> None:
         """Initialize the ArtistAlbumsWidget
 
         :param CoreArtist coreartist: The CoreArtist object
@@ -49,40 +58,22 @@ class ArtistAlbumsWidget(Gtk.ListBox):
         super().__init__()
 
         self._application = application
-        self._artist = coreartist.props.artist
+        self._artist = coreartist
         self._model = coreartist.props.model
         self._player = self._application.props.player
 
-        self._cover_size_group = Gtk.SizeGroup.new(
-            Gtk.SizeGroupMode.HORIZONTAL)
-        self._songs_grid_size_group = Gtk.SizeGroup.new(
-            Gtk.SizeGroupMode.HORIZONTAL)
-
-        self.bind_model(self._model, self._add_album)
-
-        self.get_style_context().add_class("artist-albums-widget")
-        self.props.visible = True
-
-    def _song_activated(self, widget, song_widget):
-        if self.props.selection_mode:
-            return
-
-        coremodel = self._application.props.coremodel
-
-        def _on_playlist_loaded(klass, playlist_type):
-            self._player.play(song_widget.props.coresong)
-            coremodel.disconnect(signal_id)
-
-        signal_id = coremodel.connect("playlist-loaded", _on_playlist_loaded)
-        coremodel.set_player_model(PlayerPlaylist.Type.ARTIST, self._model)
+        self._listbox.bind_model(self._model, self._add_album)
 
     def _add_album(self, corealbum):
         row = Gtk.ListBoxRow()
         row.props.selectable = False
         row.props.activatable = False
+        row.props.can_focus = False
 
-        widget = ArtistAlbumWidget(
-            corealbum, self._songs_grid_size_group, self._cover_size_group)
+        widget = AlbumWidget(self._application)
+        widget.props.corealbum = corealbum
+        widget.props.active_coreobject = self._artist
+        widget.props.show_artist_label = False
 
         self.bind_property(
             'selection-mode', widget, 'selection-mode',
@@ -90,25 +81,24 @@ class ArtistAlbumsWidget(Gtk.ListBox):
             | GObject.BindingFlags.SYNC_CREATE)
 
         row.add(widget)
-        widget.connect("song-activated", self._song_activated)
 
         return row
 
-    def select_all(self):
+    def select_all(self) -> None:
         """Select all items"""
-        def toggle_selection(row):
+        def toggle_selection(row: Gtk.ListBoxRow) -> None:
             row.get_child().select_all()
 
-        self.foreach(toggle_selection)
+        self._listbox.foreach(toggle_selection)
 
-    def deselect_all(self):
+    def deselect_all(self) -> None:
         """Deselect all items"""
-        def toggle_selection(row):
+        def toggle_selection(row: Gtk.ListBoxRow) -> None:
             row.get_child().deselect_all()
 
-        self.foreach(toggle_selection)
+        self._listbox.foreach(toggle_selection)
 
     @GObject.Property(type=str, flags=GObject.ParamFlags.READABLE)
-    def artist(self):
+    def artist(self) -> str:
         """Artist name"""
-        return self._artist
+        return self._artist.props.artist
