@@ -23,6 +23,7 @@
 # delete this exception statement from your version.
 
 from enum import IntEnum
+from typing import Optional
 
 import gi
 gi.require_version('Dazzle', '1.0')
@@ -36,7 +37,7 @@ from gnomemusic.widgets.starimage import StarImage  # noqa: F401
 
 
 @Gtk.Template(resource_path='/org/gnome/Music/ui/SongWidget.ui')
-class SongWidget(Gtk.EventBox):
+class SongWidget(Gtk.ListBoxRow):
     """The single song widget used in DiscListBox
 
     Contains
@@ -63,7 +64,9 @@ class SongWidget(Gtk.EventBox):
     _album_duration_box = Gtk.Template.Child()
     _artist_box = Gtk.Template.Child()
     _artist_label = Gtk.Template.Child()
+    _controller_motion = Gtk.Template.Child()
     _dnd_eventbox = Gtk.Template.Child()
+    _menu_button = Gtk.Template.Child()
     _select_button = Gtk.Template.Child()
     _number_label = Gtk.Template.Child()
     _title_label = Gtk.Template.Child()
@@ -172,9 +175,10 @@ class SongWidget(Gtk.EventBox):
         drag_row.props.show_song_number = self.props.show_song_number
 
         self._drag_widget.add(drag_row)
-        self._drag_widget.drag_highlight_row(drag_row.get_parent())
+        self._drag_widget.drag_highlight_row(drag_row)
         self._drag_widget.props.visible = True
-        Gtk.drag_set_icon_widget(context, self._drag_widget, x, y)
+        Gtk.drag_set_icon_widget(
+            context, self._drag_widget, x - allocation.x, y - allocation.y)
 
     @Gtk.Template.Callback()
     def _on_drag_end(self, klass, context):
@@ -182,7 +186,7 @@ class SongWidget(Gtk.EventBox):
 
     @Gtk.Template.Callback()
     def _on_drag_data_get(self, klass, context, selection_data, info, time_):
-        row_position = self.get_parent().get_index()
+        row_position = self.get_index()
         selection_data.set(
             Gdk.Atom.intern("row_position", False), 0,
             bytes(str(row_position), encoding="UTF8"))
@@ -191,7 +195,7 @@ class SongWidget(Gtk.EventBox):
     def _on_drag_data_received(
             self, klass, context, x, y, selection_data, info, time_):
         source_position = int(str(selection_data.get_data(), "UTF-8"))
-        target_position = self.get_parent().get_index()
+        target_position = self.get_index()
         if source_position == target_position:
             return
 
@@ -215,11 +219,11 @@ class SongWidget(Gtk.EventBox):
         return True
 
     @Gtk.Template.Callback()
-    def _on_star_hover(self, widget, event):
+    def _on_star_hover(self, controller, x, y):
         self._star_image.props.hover = True
 
     @Gtk.Template.Callback()
-    def _on_star_unhover(self, widget, event):
+    def _on_star_unhover(self, controller):
         self._star_image.props.hover = False
 
     @GObject.Property(type=bool, default=False)
@@ -315,3 +319,23 @@ class SongWidget(Gtk.EventBox):
             new_nr = ""
 
         self._number_label.props.label = str(new_nr)
+
+    @GObject.Property(type=Gtk.Popover, default=None)
+    def menu(self) -> Optional[Gtk.Popover]:
+        """Get the song menu.
+
+        If no menu is set, the menu button is not displayed.
+
+        :returns: song menu
+        :rtype: Gtk.PopoverMenu
+        """
+        return self._menu_button.props.popover
+
+    @menu.setter  # type: ignore
+    def menu(self, menu: Optional[Gtk.PopoverMenu]) -> None:
+        """Set song menu.
+
+        :param Gtk.PopoverMenu menu: new song menu
+        """
+        self._menu_button.props.popover = menu
+        self._menu_button.props.visible = (menu is not None)
